function D = array2db(X,Range,List,IxLog,D)
% array2db  Convert numeric array to database.
%
% Syntax
% =======
%
%     D = array2db(X,Range,List)
%
% Input arguments
% ================
%
% * `X` [ numeric ] - Numeric array with individual time series in columns.
%
% * `Range` [ numeric ] - Date range for the columns in `X`.
%
% * `List` [ cellstr | char ] - List of names for the time series in
% individual columns of `X`.
%
% Output arguments
% =================
%
% * `D` [ struct ] - Output database.
%
% Description
% ============
%
% Example
% ========
%

% -IRIS Toolbox.
% -Copyright (c) 2007-2015 IRIS Solutions Team.

%#ok<*CTCH>
%#ok<*VUNUS>

try
    IxLog; 
catch 
    IxLog = false(1,size(X,1));
end

try
    D;
catch
    D = struct();
end

if ischar(List)
    List = regexp(List,'\w+','match');
end

if ~isnumeric(X) || ~isnumeric(Range) ...
        || (~islogical(IxLog) && ~isstruct(IxLog)) || ~isstruct(D)
    error('Incorrect type of input argument(s).');
end

% TODO: Allow for unsorted dates.

%--------------------------------------------------------------------------

Range = Range(1) : Range(end);
nx = size(X,2);
nAlt = size(X,3);
nPer = length(Range);
nList = length(List);

if nx ~= nList
    utils.error('dbase:array2db', ...
        ['Number of columns in input array must match ', ...
        'number of variable names.']);
end

if size(X,1) ~= nPer
    utils.error('dbase:array2db', ...
        ['Number of rows in input array must match ', ...
        'number of periods.']);
end

template = tseries(Range,zeros(nPer,nAlt));
for i = 1 : nx
    Xi = permute(X(:,i,:),[1,3,2]);
    if (islogical(IxLog) && IxLog(i)) ...
            || (isstruct(IxLog) && IxLog.(List{i}))
        Xi = exp(Xi);
    end
    D.(List{i}) = replace(template,Xi);
end

end